@@ -10,10 +10,11 @@ let stabilize_gc_between_runs = false
 let no_compactions = false
 
 (* how long to measure *)
-let quota = Quota.Span (Time.Span.of_int_sec 10)
+let quota = Quota.Span (Time_float.Span.of_int_sec 10)
 
 (* width of the output table *)
 let limit_width_to = 200
+let max_name_length = 110
 
 (* Fork each benchmark and run in separate process *)
 let fork_each_benchmark = false
